==> piwigo-2.1.5.zip: piwigo/plugins/LocalFilesEditor/language/zh_CN/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = '本地配置';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = '模板';
$lang['locfiledit_onglet_lang'] = '语言';
$lang['locfiledit_onglet_plug'] = '个人插件';
$lang['locfiledit_cant_save'] = '当前文件不可写入。请检查 "include/" 是否可写 (chmod).';
$lang['locfiledit_newfile'] = '文件不存在，LocalFiles 编辑器将创建它';
$lang['locfiledit_save_config'] = '文件已成功写入.';
$lang['locfiledit_show_default'] = '显示相关文件: ';
$lang['locfiledit_save_bak'] = '备份将被创建和保存.';
$lang['locfiledit_saved_bak'] = '备份文件已创建 (%s)';
$lang['locfiledit_save_file'] = '保存文件';
$lang['locfiledit_choose_file'] = '选择要编辑的文件';
$lang['locfiledit_edit'] = '编辑';
$lang['locfiledit_restore'] = '恢复备份文件';
$lang['locfiledit_restore_confirm'] = '请确认? 恢复在下一次保存前将不会生效.';
$lang['locfiledit_bak_loaded1'] = '备份文件已加载.';
$lang['locfiledit_bak_loaded2'] = '您必须保存文件以便将其恢复.';
$lang['locfiledit_syntax_error'] = '语法错误! 文件不能被保存.';
$lang['locfiledit_enable_editarea'] = '启用编辑区域';
$lang['locfiledit_disable_editarea'] = '禁用编辑区域';
$lang['locfiledit_new_tpl'] = '创建新文件';
$lang['locfiledit_new_filename'] = '文件名';
$lang['locfiledit_model'] = '模块';
$lang['locfiledit_empty_page'] = '空页面';
$lang['locfiledit_parent_directory'] = '父目录';
$lang['locfiledit_filename_error'] = '被禁用的文件名.';
$lang['locfiledit_file_already_exists'] = '文件已存在.';
$lang['locfiledit_model_error'] = '您必须选择一个模块.';
$lang['locfiledit_empty_filename'] = '您必须填写文件名.';
$lang['locfiledit_webmaster_only'] = '只有网站管理员才能创建或者修改本地文件.';

?>

==> piwigo-2.1.6.zip: piwigo/plugins/LocalFilesEditor/language/zh_CN/plugin.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based picture gallery                                  |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2010 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['locfiledit_onglet_localconf'] = '本地配置';
$lang['locfiledit_onglet_css'] = 'CSS';
$lang['locfiledit_onglet_tpl'] = '模板';
$lang['locfiledit_onglet_lang'] = '语言';
$lang['locfiledit_onglet_plug'] = '个人插件';
$lang['locfiledit_cant_save'] = '当前文件不可写入。请检查 "local/" 是否可写 (chmod).';
$lang['locfiledit_newfile'] = '文件不存在，LocalFiles 编辑器将创建它';
$lang['locfiledit_save_config'] = '文件已成功写入.';
$lang['locfiledit_show_default'] = '显示相关文件: ';
$lang['locfiledit_save_bak'] = '备份将被创建和保存.';
$lang['locfiledit_saved_bak'] = '备份文件已创建 (%s)';
$lang['locfiledit_save_file'] = '保存文件';
$lang['locfiledit_choose_file'] = '选择要编辑的文件';
$lang['locfiledit_edit'] = '编辑';
$lang['locfiledit_restore'] = '恢复备份文件';
$lang['locfiledit_restore_confirm'] = '请确认? 恢复在下一次保存前将不会生效.';
$lang['locfiledit_bak_loaded1'] = '备份文件已加载.';
$lang['locfiledit_bak_loaded2'] = '您必须保存文件以便将其恢复.';
$lang['locfiledit_syntax_error'] = '语法错误! 文件不能被保存.';
$lang['locfiledit_enable_editarea'] = '启用编辑区域';
$lang['locfiledit_disable_editarea'] = '禁用编辑区域';
$lang['locfiledit_new_tpl'] = '创建新文件';
$lang['locfiledit_new_filename'] = '文件名';
$lang['locfiledit_model'] = '模块';
$lang['locfiledit_empty_page'] = '空页面';
$lang['locfiledit_parent_directory'] = '父目录';
$lang['locfiledit_filename_error'] = '被禁用的文件名.';
$lang['locfiledit_file_already_exists'] = '文件已存在.';
$lang['locfiledit_model_error'] = '您必须选择一个模块.';
$lang['locfiledit_empty_filename'] = '您必须填写文件名.';
$lang['locfiledit_webmaster_only'] = '只有网站管理员才能创建或者修改本地文件.';

?>
